# waRAG

[![Github](https://img.shields.io/static/v1?label=GitHub&message=Repo&logo=GitHub&color=green)](https://github.com/Florents-Tselai/warag)
[![PyPI](https://img.shields.io/pypi/v/warag.svg)](https://pypi.org/project/warag/)
[![Documentation Status](https://readthedocs.org/projects/warag/badge/?version=stable)](http://warag.tselai.com/en/latest/?badge=stable)
[![Linkedin](https://img.shields.io/badge/LinkedIn-0077B5?logo=linkedin&logoColor=white)](https://www.linkedin.com/in/florentstselai/)
[![Github Sponsors](https://img.shields.io/static/v1?label=Sponsor&message=%E2%9D%A4&logo=GitHub&color=pink)](https://github.com/sponsors/Florents-Tselai/)
[![pip installs](https://img.shields.io/pypi/dm/warag?label=pip%20installs)](https://pypi.org/project/warag/)
[![Tests](https://github.com/Florents-Tselai/warag/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/Florents-Tselai/warag/actions?query=workflow%3ATest)
[![codecov](https://codecov.io/gh/Florents-Tselai/warag/branch/main/graph/badge.svg)](https://codecov.io/gh/Florents-Tselai/warag)
[![License](https://img.shields.io/badge/BSD%20license-blue.svg)](https://github.com/Florents-Tselai/warag/blob/main/LICENSE)

